# Color Distance and Delta E

ColorAide Extras not only includes some experimental color spaces, but includes some associated ∆E methods as well.

Name                   | Symmetrical
---------------------- | -----------
[`cam16`](./cam16.md)  | :octicons-check-16:
